@@ -16,48 +16,58 @@ EXTRA_PACKAGES = {
     ],
     "local-generation": [
         "tqdm>=4.0",
-        "aiolimiter>=1.1",
     ],
-    "dashboard": ["plotly>=5.0.0", "streamlit>=1.23", "pyarrow>=10.0.0"],
-    "selfhosted": [
-        "tqdm>=4.0",
-        "aiolimiter>=1.1",
+    "st_classic": [
         "plotly>=5.0.0",
         "streamlit>=1.23",
         "pyarrow>=10.0.0",
-        "river<0.18",
+    ],
+    "llama-index": [
+        "llama-index>=0.8.0",
+    ],
+    "embeddings": [
+        "tqdm>=4.0",
+        "sentence-transformers",
+        "InstructorEmbedding",
+        "replicate",
+        "faiss-cpu",
+    ],
+    "openai-evals": [
+        "evals @ git+https://github.com/openai/evals.git@main",
+    ],
+    "selfhosted": [
+        "tqdm>=4.0",
+        "streamlit>=1.23",
+        "pyarrow>=10.0.0",
         "scikit-learn>=1.0.0",
         "umap-learn",
         "rouge-score",
-        "torchmetrics",
-        # "sentence-transformers",
-        # "InstructorEmbedding",
-        "openai==1.6.1",
-        "llama-index>=0.8.0",
-        "evals @ git+https://github.com/openai/evals.git@main",
         "replicate",
-        "litellm==1.15.7",
+        "litellm>=1.15.7",
         "faiss-cpu",
     ],
+    "dashboard": [
+        "tqdm>=4.0",
+        "pyarrow>=10.0.0",
+        "scikit-learn>=1.0.0",
+        "rouge-score",
+        "litellm>=1.15.7",
+    ],
     # Add packages here
     "full": [
         "tqdm>=4.0",
-        "aiolimiter>=1.1",
-        "plotly>=5.0.0",
         "streamlit>=1.23",
         "pyarrow>=10.0.0",
-        "river<0.18",
         "scikit-learn>=1.0.0",
         "umap-learn",
         "rouge-score",
         "torchmetrics",
         "sentence-transformers",
         "InstructorEmbedding",
-        "openai==1.6.1",
         "llama-index>=0.8.0",
         "evals @ git+https://github.com/openai/evals.git@main",
         "replicate",
-        "litellm==1.15.7",
+        "litellm>=1.15.7",
         "faiss-cpu",
     ],
 }
