@@ -20,6 +20,9 @@ from uptrain.operators import (
     ConversationSatisfactionScore,
     CodeHallucinationScore,
     JailbreakDetectionScore,
+    SubQueryCompleteness,
+    ContextReranking,
+    ContextConciseness,
 )
 
 
@@ -27,6 +30,7 @@ from uptrain.operators import (
 # Response Quality
 # -----------------------------------------------------------
 
+
 def CheckResponseCompleteness():
     return Check(
         name="response_completeness_score",
@@ -67,10 +71,19 @@ def CheckResponseConsistency():
     )
 
 
+def CheckResponseMatching(method="llm"):
+    return Check(
+        name="response_matching_score",
+        operators=[ResponseMatchingScore(method=method)],
+        plots=[Histogram(x="score_response_matching")],
+    )
+
+
 # -----------------------------------------------------------
 # Context Quality
 # -----------------------------------------------------------
 
+
 def CheckContextRelevance():
     return Check(
         name="score_context_relevance",
@@ -95,11 +108,27 @@ def CheckResponseFacts():
     )
 
 
+def CheckContextReranking():
+    return Check(
+        name="context_reranking_score",
+        operators=[ContextReranking()],
+        plots=[Histogram(x="score_context_reranking")],
+    )
+
+
+def CheckContextConciseness():
+    return Check(
+        name="context_conciseness_score",
+        operators=[ContextConciseness()],
+        plots=[Histogram(x="score_context_conciseness")],
+    )
+
 
 # -----------------------------------------------------------
 # Language Proficiency
 # -----------------------------------------------------------
 
+
 def CheckLanguageQuality():
     return Check(
         name="language_critique_score",
@@ -122,6 +151,7 @@ def CheckToneQuality(llm_persona):
 # Code generation
 # -----------------------------------------------------------
 
+
 def CheckCodeHallucination():
     return Check(
         name="code_hallucination_score",
@@ -134,10 +164,13 @@ def CheckCodeHallucination():
 # Conversation Quality
 # -----------------------------------------------------------
 
-def CheckConversationSatisfaction(user_persona="user", llm_persona=None):
+
+def CheckConversationSatisfaction(user_role="user", llm_role="assistant"):
     return Check(
         name="conversation_satisfaction_score",
-        operators=[ConversationSatisfactionScore(user_persona, llm_persona)],
+        operators=[
+            ConversationSatisfactionScore(user_role=user_role, llm_role=llm_role)
+        ],
         plots=[Histogram(x="score_conversation_satisfaction")],
     )
 
@@ -146,6 +179,7 @@ def CheckConversationSatisfaction(user_persona="user", llm_persona=None):
 # Custom Evaluations
 # -----------------------------------------------------------
 
+
 def CheckGuidelineAdherence(
     guideline, guideline_name="guideline", response_schema=None
 ):
@@ -162,22 +196,11 @@ def CheckGuidelineAdherence(
     )
 
 
-# -----------------------------------------------------------
-# Compare response with ground truth
-# -----------------------------------------------------------
-
-def CheckResponseMatching(method="llm"):
-    return Check(
-        name=f"{method}_score",
-        operators=[ResponseMatchingScore(method=method)],
-        plots=[Histogram(x=f"{method}_score")],
-    )
-
-
 # -----------------------------------------------------------
 # Security
 # -----------------------------------------------------------
 
+
 def CheckPromptInjection():
     return Check(
         name="prompt_injection_score",
@@ -192,3 +215,16 @@ def CheckJailbreakDetection():
         operators=[JailbreakDetectionScore()],
         plots=[Histogram(x="score_jailbreak_attempted")],
     )
+
+
+# -----------------------------------------------------------
+# Subquery
+# -----------------------------------------------------------
+
+
+def CheckSubQueryCompleteness():
+    return Check(
+        name="sub_query_completeness_score",
+        operators=[SubQueryCompleteness()],
+        plots=[Histogram(x="score_sub_query_completeness")],
+    )
