@@ -60,7 +60,7 @@ class GuidelineAdherenceScore(ColumnOp):
     guideline_name: str = "guideline"
     response_schema: t.Union[str, None] = None
     col_out: str = "score_guideline_adherence"
-    scenario_description: t.Union[str, list[str], None] = None
+    scenario_description: t.Optional[str] = None
     score_mapping: dict = {"A": 1.0, "B": 0.0}
 
     def setup(self, settings: t.Optional[Settings] = None):
@@ -68,7 +68,10 @@ class GuidelineAdherenceScore(ColumnOp):
 
         assert settings is not None
         self.settings = settings
-        if self.settings.evaluate_locally:
+        if self.settings.evaluate_locally and (
+            self.settings.uptrain_access_token is None
+            or not len(self.settings.uptrain_access_token)
+        ):
             self._api_client = LLMMulticlient(settings)
         else:
             self._api_client = APIClient(settings)
@@ -81,7 +84,10 @@ class GuidelineAdherenceScore(ColumnOp):
             row["response"] = row.pop(self.col_response)
 
         try:
-            if self.settings.evaluate_locally:
+            if self.settings.evaluate_locally and (
+                self.settings.uptrain_access_token is None
+                or not len(self.settings.uptrain_access_token)
+            ):
                 results = self.evaluate_local(data_send)
             else:
                 results = self._api_client.evaluate(
